@@ -28,7 +28,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 
 from django.contrib import admin
-from django.conf.urls.defaults import *
+from django.conf.urls import *
 from django.core.exceptions import PermissionDenied
 from django.db import transaction, models
 from django.contrib.admin.util import unquote
@@ -52,12 +52,12 @@ urls = patterns('',
 
 #noinspection PyUnusedLocal
 def mass_change_selected(modeladmin, request, queryset):
-    selected_int = queryset.values_list('id', flat=True)
+    selected_int = queryset.values_list('pk', flat=True)
     selected = []
     for s in selected_int:
         selected.append(str(s))
     return HttpResponseRedirect('../%s-masschange/%s' % (modeladmin.model._meta.module_name, ','.join(selected)))
-mass_change_selected.short_description = u'Mass Edit'
+mass_change_selected.short_description = _('Mass Edit')
 
 def mass_change_view(request, app_name, model_name, object_ids):
     model = models.get_model(app_name, model_name)
@@ -92,7 +92,6 @@ class MassAdmin(admin.ModelAdmin):
     def render_mass_change_form(self, request, context, add=False, change=False, form_url='', obj=None):
         opts = self.model._meta
         app_label = opts.app_label
-        ordered_objects = opts.get_ordered_objects()
         context.update({
             'add': add,
             'change': change,
@@ -101,13 +100,11 @@ class MassAdmin(admin.ModelAdmin):
             'has_delete_permission': self.has_delete_permission(request, obj),
             'has_file_field': True,
             'has_absolute_url': hasattr(self.model, 'get_absolute_url'),
-            'ordered_objects': ordered_objects,
             'form_url': mark_safe(form_url),
             'opts': opts,
             'content_type_id': ContentType.objects.get_for_model(self.model).id,
             'save_as': self.save_as,
             'save_on_top': self.save_on_top,
-            'onclick_attrib': (opts.get_ordered_objects() and change and 'onclick="submitOrderForm();"' or ''),
         })
         context_instance = template.RequestContext(request, current_app=self.admin_site.name)
         return render_to_response(self.change_form_template or [
@@ -122,6 +119,9 @@ class MassAdmin(admin.ModelAdmin):
         model = self.model
         opts = model._meta
         general_error = None
+
+        # Allow model to hide some fields for mass admin
+        self.exclude = getattr(self.admin_obj, "massadmin_exclude", None)
                         		
         object_ids = comma_separated_object_ids.split(',')
         object_id = object_ids[0]
@@ -179,8 +179,8 @@ class MassAdmin(admin.ModelAdmin):
                                 formsets.append(formset)
                                 
                         if all_valid(formsets) and form_validated:
-                            self.admin_obj.save_model(request, new_object, form, change=True)
-                            # self.save_model(request, new_object, form, change=True)
+			    #self.admin_obj.save_model(request, new_object, form, change=True)
+                            self.save_model(request, new_object, form, change=True)
                             form.save_m2m()
                             for formset in formsets:
                                 self.save_formset(request, form, formset, change=True)
@@ -189,7 +189,7 @@ class MassAdmin(admin.ModelAdmin):
                             self.log_change(request, new_object, change_message)
                             changed_count += 1
                             
-                    if changed_count != objects_count:
+                    if False and changed_count != objects_count:
                         raise Exception('Some of the selected objects could\'t be changed.')
                     transaction.commit()    
                     return self.response_change(request, new_object)
